summaryrefslogtreecommitdiffhomepage
path: root/digital/beacon/src/laser.h
diff options
context:
space:
mode:
Diffstat (limited to 'digital/beacon/src/laser.h')
-rw-r--r--digital/beacon/src/laser.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/digital/beacon/src/laser.h b/digital/beacon/src/laser.h
index d9d24b1e..f50c5b07 100644
--- a/digital/beacon/src/laser.h
+++ b/digital/beacon/src/laser.h
@@ -57,10 +57,13 @@ void laser_inhibit_angle_confirmation(void);
/* This function configures the AVR OC3B interrupt that will send the angle LASER_SENDING_OFFSET after the latest rising edge */
void laser_engage_angle_confirmation(uint16_t value);
-/* This function returns the angle value */
-uint16_t laser_get_angle(void);
+/* This function returns the angle value in raw format */
+uint16_t laser_get_angle_raw(void);
-/* This function sets the angle value */
-void laser_set_angle(uint16_t angle);
+/* This function returns the angle value in degrees */
+float laser_get_angle_degrees(void);
+
+/* This function sets the angle value in raw format */
+void laser_set_angle_raw(uint16_t angle);
#endif